@@ -119,11 +119,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.2.7
+Version v3.2.8
 
 =cut
 
-our $VERSION = version->declare('v3.2.7');
+our $VERSION = version->declare('v3.2.8');
 
 =head1 SYNOPSIS
 
@@ -276,6 +276,9 @@ has deb_machine => (
 	is => 'rw',
 );
 
+# TODO: drop when R::P::License v3.8.1 is required
+my $hack_3_8_1 = $Regexp::Pattern::License::VERSION < v3.8.1;
+
 sub list_licenses
 {
 	my ($self) = @_;
@@ -283,13 +286,22 @@ sub list_licenses
 	my %names;
 	for my $key ( keys %Regexp::Pattern::License::RE ) {
 		for ( keys %{ $Regexp::Pattern::License::RE{$key} } ) {
+			my %attr;
 			my @attr = split /[.]/;
-			next unless $attr[0] eq 'name';
-			my %attr = @attr[ 2 .. $#attr ];
 
-			# TODO: drop version check when R::P::License v3.8.1 is required
-			for (qw(until version)) {
-				next if exists $attr{$_};
+			next unless $attr[0] eq 'name';
+
+			# TODO: simplify when R::P::License v3.8.1 is required
+			if ($hack_3_8_1) {
+				push @attr, undef
+					if @attr % 2;
+				%attr = @attr[ 2 .. $#attr ];
+				next if exists $attr{version};
+				next if exists $attr{until};
+			}
+			else {
+				%attr = @attr[ 2 .. $#attr ];
+				next if exists $attr{until};
 			}
 			for my $org ( @{ $self->shortname_scheme } ) {
 				if ( exists $attr{$org} ) {
